@@ -115,20 +115,20 @@ class PubSub(object):
         kafka_admin.create_topics(new_topic_list)
 
     def emit(self, event, message, emit=False):
-        formatted_event = "%s%s" % (self.kafka_emit_prefix, event)
         # Convert dict to string
         message_str = json.dumps(message)
-        logger.debug(" [x] Sent %r:%r" % (formatted_event, message_str))
+        logger.debug(" [x] Sent %r:%r" % (event, message_str))
 
         if not emit:
             return
 
         self.connection = redis.StrictRedis(host=self.host, port=self.port, db=self.database)
         self.pubsub = self.connection.pubsub()
-        self.connection.publish(channel=formatted_event, message=message_str)
+        self.connection.publish(channel=event, message=message_str)
         self.pubsub.close()
 
         if self.enable_kafka:
+            formatted_event = "%s%s" % (self.kafka_emit_prefix, event)
             kafka_producer = self.get_kafka_producer()
             future = kafka_producer.send(formatted_event, message_str.encode("utf-8"))
             # Should we wait and make sure it is sent ?
